import es
import services
import services.auth

info = es.AddonInfo()
info.name = "NameAuth"
info.version = "1.1"
info.author = "GODJonez"
info.description = "Very simple auth provider to auth people by their in-game name"
info.basename = "nameauth"
info.url = "http://addons.eventscripts.com/addons/view/nameauth"

admin_names = es.ServerVar('nameauth_admins', '', 'Names of server admins, separate with semicolons')


def load():
    '''
    Initialize addon, triggered by es_load nameauth
    '''
    authinst = NameAuthService()
    services.register("auth", authinst)

def unload():
    '''
    Remove auth service, triggered by es_unload nameauth
    '''
    services.unregister("auth")

class NameAuthService(services.auth.AuthorizationService):
    '''
    The auth service itself
    '''

    def __init__(self):
        '''
        Initialize class instance
        '''
        self.fallbackdata = dict()
    
    def registerCapability(self, auth_capability, auth_recommendedlevel):
        '''
        Registers a capability with a recommended level
        '''
        self.fallbackdata[auth_capability] = int(auth_recommendedlevel)
        return True
    
    def isUseridAuthorized(self, auth_userid, auth_capability):
        '''
        Returns boolean information about if the specified userid is allowed to
        use the specified capability
        '''
        user = self.getOfflineIdentifier(auth_userid)
        data = self.isIdAuthorized(user, auth_capability)
        return data
    
    def getOfflineIdentifier(self, auth_userid):
        '''
        Returns an identifier used to actually get the player permission
        '''
        return es.getplayername(auth_userid)
    
    def isIdAuthorized(self, auth_identifier, auth_capability):
        '''
        Returns boolean information on whether the player is allowed to use
        the specified capability, using the indetifier given by
        getOfflineIdentifier
        '''

        admins = str(admin_names).split(';')
        if auth_identifier in admins:
            return True
        if auth_capability in self.fallbackdata:
            if self.fallbackdata[auth_capability] <= self.USER:
                return True
        return False
